#!/bin/sh

#
set -ux

# Run Chrome.
docker run -d --rm \
  -e SCREEN_WIDTH=1920 \
  -e SCREEN_HEIGHT=1080 \
  -e TZ=US/Eastern \
  -e GRID=false \
  -e CHROME=true \
  -e FIREFOX=false \
  -e SELENIUM_HUB_HOST=webdriver \
  -e SELENIUM_HUB_PORT=24444 \
  -e SELENIUM_NODE_HOST="{{CONTAINER_IP}}" \
  -e USE_SELENIUM=3 \
  -e VIDEO=true \
  -v /dev/shm:/dev/shm \
  -v $BUILDKITE_BUILD_CHECKOUT_PATH/tmp/videos:/videos \
  --network webdriver-net \
  --name vueform-chrome-$BUILDKITE_COMMIT \
  elgalu/selenium:3.3.1-p17

# Run Firefox.
docker run -d --rm \
  -e SCREEN_WIDTH=1920 \
  -e SCREEN_HEIGHT=1080 \
  -e TZ=US/Eastern \
  -e GRID=false \
  -e CHROME=false \
  -e FIREFOX=true \
  -e SELENIUM_HUB_HOST=webdriver \
  -e SELENIUM_HUB_PORT=24444 \
  -e SELENIUM_NODE_HOST="{{CONTAINER_IP}}" \
  -e USE_SELENIUM=3 \
  -e VIDEO=true \
  -v /dev/shm:/dev/shm \
  -v $BUILDKITE_BUILD_CHECKOUT_PATH/tmp/videos:/videos \
  --network webdriver-net \
  --name vueform-firefox-$BUILDKITE_COMMIT \
  elgalu/selenium:3.3.1-p17

# Run Caddy that serves VueForm.
docker run -d --rm \
  --network webdriver-net \
  --name vueform-$BUILDKITE_COMMIT \
  optick/vueform:$BUILDKITE_COMMIT

# Sleep for 5 seconds.
sleep 5

# Run end-to-end tests.
docker run --rm \
  -e WEBDRIVER_HOST=webdriver \
  -e WEBDRIVER_PORT=24444 \
  -e BASE_URL=http://vueform-$BUILDKITE_COMMIT/ \
  --network webdriver-net \
  optick/vueform:$BUILDKITE_COMMIT npm test

# Capture the exit status.
TESTS_EXIT_STATUS=$?

docker kill vueform-$BUILDKITE_COMMIT
docker kill vueform-chrome-$BUILDKITE_COMMIT
docker kill vueform-firefox-$BUILDKITE_COMMIT

# Exit with the status of the test command.
exit $TESTS_EXIT_STATUS
